//
//  ChannelLayout.m
//

#import "ChannelLayout.h"
#import <CoreAudio/CoreAudioTypes.h>

channelLayout_t channelLayouts[numberOfChannelLayouts] = {
	{
		0,
		@"Original",
		@"Same channel layout as in the input file"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_DiscreteInOrder, // needs to be ORed with the actual number of channels
		@"Discrete in order",
		@"Discrete In Order"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_Mono,
		@"Mono",
		@"A standard mono stream"
	},
	{
		kAudioChannelLayoutTag_Stereo,
		@"Stereo",
		@"A standard stereo stream (left, right,) - implied playback"
	},
	{
		kAudioChannelLayoutTag_StereoHeadphones,
		@"Stereo headphones",
		@"A standard stereo stream (left, right,) - implied headphone playback"
	},
	{
		kAudioChannelLayoutTag_MatrixStereo,
		@"Matrix stereo",
		@"A matrix encoded stereo stream (left matrix total,, right matrix total,)"
	},
	{
		kAudioChannelLayoutTag_MidSide,
		@"Mid / Side",
		@"Mid/side recording"
	},
	{
		kAudioChannelLayoutTag_XY,
		@"XY",
		@"Coincident mic pair (often 2 figure 8's)"
	},
	{
		kAudioChannelLayoutTag_Binaural,
		@"Binaural",
		@"Binaural stereo (left, right)"
	},
	{
		kAudioChannelLayoutTag_Ambisonic_B_Format,
		@"Ambisonic B format",
		@"W, X, Y, Z"
	},
	{
		kAudioChannelLayoutTag_Quadraphonic,
		@"Quadraphonic",
		@"Front left, front right, back left, back right"
	},
	{
		kAudioChannelLayoutTag_Pentagonal,
		@"Pentagonal",
		@"Left, right, rear left, rear right, center"
	},
	{
		kAudioChannelLayoutTag_Hexagonal,
		@"Hexagonal",
		@"Left, right, rear left, rear right, center, rear"
	},
	{
		kAudioChannelLayoutTag_Octagonal,
		@"Octagonal",
		@"Front left, front right, rear left, rear right, front center, rear center, side left, side right"
	},
	{
		kAudioChannelLayoutTag_Cube,
		@"Cube",
		@"Left, right, rear left, rear right, top left, top right, top rear left, top rear right"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_MPEG_3_0_A,
		@"MPEG 3.0 A",
		@"Left, right, center"
	},
	{
		kAudioChannelLayoutTag_MPEG_3_0_B,
		@"MPEG 3.0 B",
		@"Center, left, right"
	},
	{
		kAudioChannelLayoutTag_MPEG_4_0_A,
		@"MPEG 4.0 A",
		@"Left, right, center, center surround"
	},
	{
		kAudioChannelLayoutTag_MPEG_4_0_B,
		@"MPEG 4.0 B",
		@"Center, left, right, center surround"
	},
	{
		kAudioChannelLayoutTag_MPEG_5_0_A,
		@"MPEG 5.0 A",
		@"Left, right, center, left surround, right surround"
	},
	{
		kAudioChannelLayoutTag_MPEG_5_0_B,
		@"MPEG 5.0 B",
		@"Left, right, left surround, right surround, center"
	},
	{
		kAudioChannelLayoutTag_MPEG_5_0_C,
		@"MPEG 5.0 C",
		@"Left, center, right, left surround, right surround"
	},
	{
		kAudioChannelLayoutTag_MPEG_5_0_D,
		@"MPEG 5.0 D",
		@"Center, left, right, left surround, right surround"
	},
	{
		kAudioChannelLayoutTag_MPEG_5_1_A,
		@"MPEG 5.1 A",
		@"Left, right, center, low frequency effects, left surround, right surround"
	},
	{
		kAudioChannelLayoutTag_MPEG_5_1_B,
		@"MPEG 5.1 B",
		@"Left, right, left surround, right surround, center, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_MPEG_5_1_C,
		@"MPEG 5.1 C",
		@"Left, center, right, left surround, right surround, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_MPEG_5_1_D,
		@"MPEG 5.1 D",
		@"Center, left, right, left surround, right surround, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_MPEG_6_1_A,
		@"MPEG 6.1 A",
		@"Left, right, center, low frequency effects, left surround, right surround, center surround"
	},
	{
		kAudioChannelLayoutTag_MPEG_7_1_A,
		@"MPEG 7.1 A",
		@"Left, right, center, low frequency effects, left surround, right surround, left center, right center"
	},
	{
		kAudioChannelLayoutTag_MPEG_7_1_B,
		@"MPEG 7.1 B",
		@"Center, left center, right center, left, right, left surround, right surround, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_MPEG_7_1_C,
		@"MPEG 7.1 C",
		@"Left, right, center, low frequency effects, left surround, right surround, rear left surround, rear right surround"
	},
	{
		kAudioChannelLayoutTag_Emagic_Default_7_1,
		@"Emagic default 7.1",
		@"Left, right, left surround, right surround, center, low frequency effects, left center, right center"
	},
	{
		kAudioChannelLayoutTag_SMPTE_DTV,
		@"SMPTE DTV",
		@"Left, right, center, low frequency effects, left surround, right surround, left matrix total, right matrix total, (ITU 5.1 plus a matrix encoded stereo mix)"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_ITU_2_1,
		@"ITU 2.1",
		@"Left, right, center surround"
	},
	{
		kAudioChannelLayoutTag_ITU_2_2,
		@"ITU 2.2",
		@"Left, right, left surround, right surround"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_ITU_3_2,
		@"ITU 3.2",
		@"Left, right, center, left surround, right surround"
	},
	{
		kAudioChannelLayoutTag_ITU_3_2_1,
		@"ITU 3.2.1",
		@"Left, right, center, low frequency effects, left surround, right surround"
	},
	{
		kAudioChannelLayoutTag_ITU_3_4_1,
		@"ITU 3.4.1",
		@"Left, right, center, low frequency effects, left surround, right surround, rear left surround, rear right surround"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_DVD_4,
		@"DVD 4",
		@"Left, right, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_DVD_5,
		@"DVD 5",
		@"Left, right, low frequency effects, center surround"
	},
	{
		kAudioChannelLayoutTag_DVD_6,
		@"DVD 6",
		@"Left, right, low frequency effects, left surround, right surround"
	},
	{
		kAudioChannelLayoutTag_DVD_10,
		@"DVD 10",
		@"Left, right, center, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_DVD_11,
		@"DVD 11",
		@"Left, right, center, low frequency effects, center surround"
	},
	{
		kAudioChannelLayoutTag_DVD_18,
		@"DVD 18",
		@"Left, right, left surround, right surround, low frequency effects"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_AudioUnit_6_0,
		@"AudioUnit 6.0",
		@"Left, right, left surround, right surround, center, center surround"
	},
	{
		kAudioChannelLayoutTag_AudioUnit_7_0,
		@"AudioUnit 7.0",
		@"Left, right, left surround, right surround, center, rear left surround, rear right surround"
	},
	{
		kAudioChannelLayoutTag_AudioUnit_7_0_Front,
		@"AudioUnit 7.0 front",
		@"Left, right, left surround, right surround, center, left center, right center"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_AAC_6_0,
		@"AAC 6.0",
		@"Center, left, right, left surround, right surround, center surround"
	},
	{
		kAudioChannelLayoutTag_AAC_6_1,
		@"AAC 6.1",
		@"Center, left, right, left surround, right surround, center surround, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_AAC_7_0,
		@"AAC 7.0",
		@"Center, left, right, left surround, right surround, rear left surround, rear right surround"
	},
	{
		kAudioChannelLayoutTag_AAC_Octagonal,
		@"AAC Octagonal",
		@"Center, left, right, left surround, right surround, rear left surround, rear right surround, center surround"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_TMH_10_2_std,
		@"TMH 10.2 std",
		@"Left, right, center, vertical height center, left surround direct, right surround direct, left surround, right surround, vertical height left, vertical height right, left wide, right wide, center surround direct, center surround, low frequency effects 1, low frequency effects 2"
	},
	{
		kAudioChannelLayoutTag_TMH_10_2_full,
		@"TMH 10.2 full",
		@"TMH 10.2 std plus: left center, right center, HI, VI, haptic"
	},
	{
		0,
		nil,
		nil
	},
	{
		kAudioChannelLayoutTag_AC3_1_0_1,
		@"AC3 1.0.1",
		@"Center, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_AC3_3_0,
		@"AC3 3.0",
		@"Left, center, right"
	},
	{
		kAudioChannelLayoutTag_AC3_3_1,
		@"AC3 3.1",
		@"Left, center, right, center surround"
	},
	{
		kAudioChannelLayoutTag_AC3_3_0_1,
		@"AC3 3.0.1",
		@"Left, center, right, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_AC3_2_1_1,
		@"AC3 2.1.1",
		@"Left, right, center surround, low frequency effects"
	},
	{
		kAudioChannelLayoutTag_AC3_3_1_1,
		@"AC3 3.1.1",
		@"Left, center, right, center surround, low frequency effects"
	}
};
