//
//  FeedbackController.m
//

#import "FeedbackController.h"
#import "Functions.h"
#import "MainController.h"

@interface FeedbackController ()

@property (assign) uint64_t lastSeconds;

- (NSString *)errorContextString;
- (NSString *)listStringWithNames:(NSArray *)names;

@end

@implementation FeedbackController

//--------------------------------------
#pragma mark property implementations

synth(progressTextField);
synth(progressIndicator);
synth(remainingTimeTextField);
synth(errorContextTextField);
synth(faultyFilesTextView);
synth(mainController);

synth(lastSeconds);

//--------------------------------------
#pragma mark protocol methods

- (void)feedbackTotalInputSize:(uint64_t)size
{
	[_progressIndicator setMaxValue:size];
}

- (void)feedbackCurrentFileName:(NSString *)name
{
	NSString *labelString = [NSString stringWithFormat:@"Converting “%@”…", name];
	[_progressTextField setStringValue:labelString];
}

- (void)feedbackProgress:(double)progress
{
	[_progressIndicator setDoubleValue:progress];
}

- (void)feedbackRemainingTime:(double)nanoseconds
{
	uint64_t seconds = cast(uint64_t)(nanoseconds / 1.0E+9);
	if (seconds != _lastSeconds) {
		[self setLastSeconds:seconds];
		NSString *estimation = timeEstimationFromSeconds(seconds);
		[_remainingTimeTextField setStringValue:estimation];
	}
}

- (void)feedbackFaultyInputNames:(NSArray *)names
{
	NSString *contextString = [self errorContextString];
	[_errorContextTextField setStringValue:contextString];
	NSString *listString = [self listStringWithNames:names];
	[_faultyFilesTextView setFont:[NSFont systemFontOfSize:13]];
	[_faultyFilesTextView setString:listString];
	[_mainController showErrorView];
}

- (void)feedbackSuccess
{
	[_mainController showSuccessView];
}

//--------------------------------------
#pragma mark public methods

- (IBAction)stop:(id)sender
{
	[_progressIndicator setIndeterminate:YES];
	[_mainController stop];
}

- (IBAction)restart:(id)sender
{
	[_mainController showOptionsView];
}

- (void)resetProgressView
{
	[_progressIndicator setIndeterminate:NO];
	[_progressIndicator setMaxValue:1.0];
	[_progressIndicator setDoubleValue:0.0];
	[_progressTextField setStringValue:@"Converting…"];
	[_remainingTimeTextField setStringValue:@"Unknown"];
}

//--------------------------------------
#pragma mark private methods

- (NSString *)errorContextString
{
	if ([_mainController isInterrupted])
		return @"(Conversion was interrupted by the user.)";
	else if ([_mainController usesVariableBitRate])
		return @"(Please try a lower bit rate for these files.)";
	else
		return @"";
}

- (NSString *)listStringWithNames:(NSArray *)names
{
	unsigned long count = [names count];
	NSMutableString *listString = [NSMutableString stringWithCapacity:(count * (FILENAME_MAX + 1))];
	for (NSString *name in names) {
		[listString appendString:name];
		[listString appendString:@"\n"];
	}
	return listString;
}

@end
