//
//  Functions.m
//

#import "Functions.h"
#import <mach/mach_time.h>
#import <CoreServices/CoreServices.h>

uint64_t fileSize(NSString *path)
{
	struct stat fileStat;
	int status = stat([path UTF8String], &fileStat);
	return (status == 0) ? cast(uint64_t)fileStat.st_size : 0;
}

typedef union {
	uint64_t whole;
	UnsignedWide halfs;
} UintPair_t;

uint64_t nanosecondsSinceBoot(void)
{
	UintPair_t ticks, nanoseconds;
	ticks.whole = mach_absolute_time();
	nanoseconds.halfs = AbsoluteToNanoseconds(ticks.halfs);
	return nanoseconds.whole;
}

#define estimationRevisionRatio (63.0 / 64.0)

double progressEstimation(uint64_t t, double v, uint64_t x_max)
{
	if (v == 0 || x_max == 0)
		return 0;
	double x1 = estimationRevisionRatio * x_max;
	double t1 = x1 / v;
	if (t < t1)
		return (v * t);
	else {
		double alpha = x_max - x1;
		double delta_t = t - t1;
		double delta_x = alpha * (1.0 - exp(-((v / alpha) * delta_t)));
		return (x1 + delta_x);
	}
}

unsigned systemVersion(void)
{
	int major, minor, bugFix;
	Gestalt(gestaltSystemVersionMajor, &major);
	Gestalt(gestaltSystemVersionMinor, &minor);
	Gestalt(gestaltSystemVersionBugFix, &bugFix);
	return ((cast(unsigned)major & 0x0ff) << 16) | ((cast(unsigned)minor & 0x0ff) << 8) | (cast(unsigned)bugFix & 0x0ff);
}

//--------------------------------------

typedef struct {
	unsigned secondsPerUnit;
	NSString * __unsafe_unretained nouns[2];
} timeUnit_t;

#define numberOfTimeUnits 6

static timeUnit_t timeUnits[numberOfTimeUnits] = {
	{ (365 * 24 * 3600), { @"year", @"years" } },
	{ (30 * 24 * 3600), { @"month", @"months" } },
	{ (24 * 3600), { @"day", @"days" } },
	{ 3600, { @"hour", @"hours" } },
	{ 60, { @"minute", @"minutes" } },
	{ 1, { @"second", @"seconds" } }
};

NSString *timeEstimationFromSeconds(uint64_t seconds)
{
	NSString *estimation;
	if (seconds < 60) {
		NSString *noun = (seconds < 2) ? @"second" : @"seconds";
		estimation = [NSString stringWithFormat:@"%qu %@", seconds, noun];
	}
	else {
		uint64_t n1, remainder, n2;
		timeUnit_t *greaterUnitPtr = timeUnits;
		do {
			n1 = seconds / greaterUnitPtr->secondsPerUnit;
			remainder = seconds % greaterUnitPtr->secondsPerUnit;
			if (n1 > 0)
				break;
			greaterUnitPtr++;
		} while (greaterUnitPtr->secondsPerUnit > 1);
		timeUnit_t *smallerUnitPtr = greaterUnitPtr + 1;
		n2 = remainder / smallerUnitPtr->secondsPerUnit;
		unsigned i1 = (n1 > 1) ? 1 : 0;
		unsigned i2 = (n2 > 1) ? 1 : 0;
		estimation = [NSString stringWithFormat:@"%qu %@ and %qu %@",
					  n1, greaterUnitPtr->nouns[i1], n2, smallerUnitPtr->nouns[i2]];
	}
	return estimation;
}
